:mod:`eulfedora.xml` - Fedora XML objects (for REST API returns)
================================================================

Currently, this module consists of :class:`~eulxml.xmlmap.XmlObject` wrappers
for the XML returned by the REST API, to simplify dealing with results.

.. automodule:: eulfedora.xml
    :members:
